@@ -10,12 +10,15 @@
 use strict;
 use warnings;
 package Dist::Zilla::Plugin::CheckExtraTests;
-our $VERSION = '0.002';
+BEGIN {
+  $Dist::Zilla::Plugin::CheckExtraTests::VERSION = '0.003';
+}
 # ABSTRACT: check xt tests before release
 
 # Dependencies
+use Dist::Zilla 2.100950 (); # XXX really the next release after this date
 use App::Prove 3.00 ();
-use File::chdir 0.1002 ();
+use File::pushd 0 ();
 use Moose 0.99;
 use namespace::autoclean 0.09;
 
@@ -31,7 +34,7 @@ sub before_release {
   $self->zilla->ensure_built_in;
 
   # chdir in
-  local $File::chdir::CWD = $self->zilla->built_in; 
+  my $wd = File::pushd::pushd($self->zilla->built_in);
 
   # prove xt
   local $ENV{RELEASE_TESTING} = 1;
@@ -55,7 +58,7 @@ Dist::Zilla::Plugin::CheckExtraTests - check xt tests before release
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
